==> v.0.1.0.tar.gz: liebling/README.md <==
# Liebling

Liebling is a beautiful and clean Ghost theme that is easy and comfortable to use. **It's free** and you can use it for any kind of content you might have.

If you use it and you like it, please consider to make a donation to support its development! 🙏🏼

<a href="https://www.buymeacoffee.com/eddiesigner" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/black_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

## Preview

You can see a live demo here: [https://liebling.eduardogomez.io](https://liebling.eduardogomez.io)

![](https://res.cloudinary.com/edev/image/upload/v1557074150/liebling/liebling-promo-ipad.jpg)
<br><br>
![](https://res.cloudinary.com/edev/image/upload/v1557074150/liebling/liebling-promo-mobile.jpg)

## Download

To download the latest version please head over the [releases page](https://github.com/eddiesigner/liebling/releases) and click on the zip link from the latest release.

## Features

### General features

* Clean and beautiful design 💅🏼
* Lightning fast ⚡️
* Fully responsive, looks great on any device 📱
* Compatible with modern browsers 💻
* Fast support 📞

### Ghost features

* Subscription form
* Multiple authors
* Logo support
* Featured posts and pages
* Post, Page, Tag, Authors, pages
* Koenig editor
* Gallery card
* Blog title and description
* Cover image for Home, Post, Page, Tag, Author pages
* Author avatar, bio, location, website and social links
* Facebook and Twitter social links
* Reading time
* Next and Previous post navigation
* Primary tag in posts

### Liebling unique features

* Search
* Custom Subscribe page
* Custom authors page
* Custom error page
* Medium style image zoom
* Comments with Disqus
* Share post on Facebook and Twitter
* Slider for featured posts
* Support for normal, wide and full images in posts
* Reading progress indicator

## Theme tested

* W3C Markup Validation: [Correct validation](https://validator.w3.org/nu/?doc=https%3A%2F%2Fliebling.eduardogomez.io%2F)
* Ghost GScan: [100/100 points](https://gscan.ghost.org/)
* GTmetrix PageSpeed Score: **A (97%)**
* PageSpeed Insights: **94/100** (mobile) **99/100** (desktop)
* Pingdom Performance Grade: **A 91**

## Help and Support

If you have any questions or troubles with this product, please feel free to open an issue [here](https://github.com/eddiesigner/liebling/issues).

## License

Copyright (c) 2018-2019 Eduardo Gómez. Released under the [MIT license](https://github.com/eddiesigner/liebling/blob/master/LICENSE).

## Credits

All photos I used on this theme are from [Unsplash](https://unsplash.com)

==> v.0.2.8.tar.gz: liebling/README.md <==
# Liebling

Liebling is a beautiful and clean Ghost theme that is easy and comfortable to use. **It's free** and you can use it for any kind of content you might have.

If you use it and you like it, please consider to make a donation to support its development! 🙏🏼

<a href="https://www.buymeacoffee.com/eddiesigner" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/black_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

## Preview

You can see a live demo here: [https://liebling.eduardogomez.io](https://liebling.eduardogomez.io)

![](https://res.cloudinary.com/edev/image/upload/v1557074150/liebling/liebling-promo-ipad.jpg)
<br><br>
![](https://res.cloudinary.com/edev/image/upload/v1557074150/liebling/liebling-promo-mobile.jpg)

## Download

To get the latest version please head over the [releases page](https://github.com/eddiesigner/liebling/releases) and download the file `liebling.zip` of the latest release.

## Features

### General features

* Clean and beautiful design 💅🏼
* Lightning fast ⚡️
* Fully responsive, looks great on any device 📱
* Compatible with modern browsers 💻
* Fast support 📞

### Ghost features

* Subscription form
* Multiple authors
* Logo support
* Featured posts and pages
* Post, Page, Tag, Authors, pages
* Koenig editor
* Gallery card
* Blog title and description
* Cover image for Home, Post, Page, Tag, Author pages
* Author avatar, bio, location, website and social links
* Facebook and Twitter social links
* Reading time
* Next and Previous post navigation
* Primary tag in posts

### Liebling unique features

* Search
* Custom Subscribe page
* Custom authors page
* Custom error page
* Medium style image zoom
* Comments with Disqus
* Share post on Facebook and Twitter
* Slider for featured posts
* Support for normal, wide and full images in posts
* Reading progress indicator

## Localization

* English
* Spanish
* German by [D3473R](https://github.com/D3473R)
* Informal german by [D3473R](https://github.com/D3473R)
* Bulgarian by [clappingmonkey](https://github.com/clappingmonkey)
* Vietnamese by [hiensarahly](https://github.com/hiensarahly)
* Italian by [vignini](https://github.com/vignini)

## Theme tested

* W3C Markup Validation: [Correct validation](https://validator.w3.org/nu/?doc=https%3A%2F%2Fliebling.eduardogomez.io%2F)
* Ghost GScan: [100/100 points](https://gscan.ghost.org/)
* GTmetrix PageSpeed Score: **A (97%)**
* PageSpeed Insights: **94/100** (mobile) **99/100** (desktop)
* Pingdom Performance Grade: **A 91**

## Theme development

Thanks to [D3473R](https://github.com/D3473R) 💪🏼 for create a development environment with Docker. From now on you can work on this theme without installing a Ghost instance on your local machine. With two commands you have an instant development setup and you can build the theme for production.

Please take a look to this page to see how it works: https://github.com/eddiesigner/liebling/wiki/Theme-development-with-Docker

## Help and Support

To enable the search, comments, subscribers and so on, you must follow the steps found in the [Wiki](https://github.com/eddiesigner/liebling/wiki).

If you have any questions or troubles with this product, please feel free to open an issue [here](https://github.com/eddiesigner/liebling/issues).

## License

Copyright (c) 2018-2019 Eduardo Gómez. Released under the [MIT license](https://github.com/eddiesigner/liebling/blob/master/LICENSE).

## Credits

All photos I used on this theme are from [Unsplash](https://unsplash.com)
